@@ -83,7 +83,7 @@ class lucia_start (dialogue.base):
 		_("He is singing. Talan sometimes leaves his post to practice his voice where nobody hears him. That's nothing bad, but he'd be more than embarrassed if you tell it around. And I fear Jelom won't take it very well."),\
 		_("And he'd be right! Singing might not be bad, but leaving ones post during duty is! I think I'll have to have a serious word with Talan. If you'll excuse me, madam."),\
 		_("I ... I cannot tell. I have said more than I should have already."),\
-		_("I can't promise anything before I don't know what you are talking about."),\
+		_("I can't promise anything before I know what you are talking about."),\
 		_("I want no harm done to Talan, see. He is a good lad, and he deserves better than ending like Jelom. Don't destroy the chance to make something out of his life."),\
 		_("I don't want anybody harm, but I will do what I must to find the thief."),\
 		_("Please Lucia. If it has anything to do with the theft, I need to know! Don't you want the real thief caught?"),\
@@ -96,7 +96,7 @@ class lucia_start (dialogue.base):
 		_("Come back to hold me off my work again, did you?"),\
 		_("I'm afraid so. I'd like you to repeat what you've heard the night of the theft."),\
 		_("I already told you everything I know, but if you insist."),\
-		_("As I said, we're sleeping under the roof, whereas poor Master Fingolson has his room down below ground. So if he hasn't heard anything, how should i?"),\
+		_("As I said, we're sleeping under the roof, whereas poor Master Fingolson has his room down below ground. So if he hasn't heard anything, how should I?"),\
 		_("Lucia does not even bother to look up from her work as you approach her."),\
 		_("Excuse me Lucia, I have ..."),\
 		_("Don't even think of asking me for anything. The way you let Talan down, even though you gave your word not to, makes me sick."),\
