@@ -45,7 +45,7 @@ class orloth_start (dialogue.base):
 		_("The landlord calls for Oliver, the boy you met outside, and shortly afterwards he enters the common room to show the way to your chamber."),\
 		_("That's Lucia, all right. Did she go on about Lenhart again? He's my elder brother. Inherited the business from our father, although he never really liked it out here. So he asked me to buy the Inn."),\
 		_("See, I was a carter's apprentice in Erinsford back then, and the prospect of taking over at Waste's Edge instead was very appealing. Lucia and I had just married, and the dowry would have nearly paid for the Inn."),\
-		_("But I am forgetting myself. Lucia's right when she says I'd talk too much. Not that she is much better in that respect. Excuse my rambling, $name.. There must be other things you want to know."),\
+		_("But I am forgetting myself. Lucia's right when she says I'd talk too much. Not that she is much better in that respect. Excuse my rambling, $name. There must be other things you want to know."),\
 		_("I'm making progress, but I still need more information."),\
 		_("Well, I'll do my best to be of some help. Just ask your questions."),\
 		_("I don't mean to pry, but I couldn't help to notice your wife's dislike of Waste's Edge."),\
