@@ -14,7 +14,7 @@
 
 import adonthell
 
-class character_speak:
+class character_speak(object):
 
     # Parameters:
     # name: name of the character that should speak when the event is triggered
@@ -26,3 +26,10 @@ class character_speak:
 
     def run (self, submap, x, y, dir, name):
         self.mapchar.speak (self.sentence)
+        if submap == 4:
+            if x == 7 and y == 3:
+                adonthell.achievements.update(1, 11)
+            if x == 7 and y == 5:
+                adonthell.achievements.update(1, 21)
+            if x == 8 and y == 4:
+                adonthell.achievements.update(1, 31)
