@@ -14,7 +14,7 @@
 
 import adonthell
 
-class speak:
+class speak(object):
 
     # Parameters:
     # speaker: name of character that shall speak
