@@ -18,7 +18,7 @@
 import adonthell
 import events
 
-class teleport:
+class teleport(object):
 
     # Parameters:
     # smdest: destination submap
