@@ -18,7 +18,7 @@ import adonthell
 def switch_submap (mychar, x, y, submap, dir):
     # -- deactivate schedule during teleport
     if mychar.is_schedule_activated ():
-        mychar.set_schedule_active (0)
+        mychar.set_schedule_active (False)
         schedule_active = 1
     else:
         schedule_active = 0
@@ -34,4 +34,4 @@ def switch_submap (mychar, x, y, submap, dir):
 
     # -- restore character's schedule
     if schedule_active == 1:
-        mychar.set_schedule_active (1)
+        mychar.set_schedule_active (True)
