@@ -56,7 +56,9 @@ class option_screen (adonthell.win_container):
             ("fr_FR", u("Fran\\"+"xe7ais")), \
             ("it_IT", "Italiano"), \
             ("nl_NL", "Nederlands"), \
-            ("sv_SE", "Svenska")]
+            ("pt_BR", u("Portugu\\"+"xeas do Brasil")), \
+            ("sv_SE", "Svenska"), \
+            ("tr_TR", u("T\\"+"xfcrk\\"+"xe7e"))]
         
         self.current_values = []
         self.config = adonthell.config()
@@ -69,8 +71,8 @@ class option_screen (adonthell.win_container):
         self.font = adonthell.win_manager_get_font ("original")
         self.theme = adonthell.win_manager_get_theme ("original")
         
-        self.move (50, 55)
-        self.resize (220, 120)
+        self.move (45, 55)
+        self.resize (230, 120)
         self.set_border (self.theme)
         self.set_background (self.theme)
         self.set_trans_background (True)
@@ -78,7 +80,7 @@ class option_screen (adonthell.win_container):
         # -- list of options
         self.option_list = adonthell.win_select()
         self.option_list.move (10, 5)
-        self.option_list.resize (200, 110)
+        self.option_list.resize (210, 110)
         self.option_list.set_layout (adonthell.win_container_LIST_LAYOUT)
         self.option_list.thisown = 0
 
@@ -145,7 +147,7 @@ class option_screen (adonthell.win_container):
 
             label3 = adonthell.win_label()
             label3.resize (10, 20)
-            label3.move (185, 0)
+            label3.move (200, 0)
             label3.set_font (self.font)
             label3.set_text (">")
             label3.pack ()
@@ -161,14 +163,14 @@ class option_screen (adonthell.win_container):
         label4.set_form (adonthell.label_AUTO_SIZE)
         label4.set_text (value)
         label4.pack ()
-        label4.move (95 + (90 - label4.length())//2, 0)
+        label4.move (95 + (100 - label4.length())//2, 0)
         label4.thisown = 0
 
         self.current_values.append(label4)
 
         container.add(label4)        
         container.move(0, 0)
-        container.resize (200, 15)
+        container.resize (210, 15)
         container.set_visible_all (True)
         
         return container
@@ -249,6 +251,6 @@ class option_screen (adonthell.win_container):
             label.set_text(new_language[1])
 
         if label != None:
-            label.move (100 + (80 - label.length())//2, 0)
+            label.move (100 + (90 - label.length())//2, 0)
             label.pack()
-            
\ No newline at end of file
+            
