@@ -15,7 +15,7 @@
 #    He'll walk between his table and the bar
 
 import adonthell
-import schedule
+from schedules.mapcharacters import schedule
 import random
 
 def _(message): return message
