@@ -16,7 +16,7 @@
 
 import adonthell
 import random
-import schedule
+from schedules.mapcharacters import schedule
 
 def _(message): return message
 
